@@ -9,8 +9,7 @@ module RuboCop
       #
       # @safety
       #   This cop is unsafe because it has known compatibility issues with `ActiveRecord` and other
-      #   frameworks. ActiveRecord's `count` ignores the block that is passed to it.
-      #   `ActiveRecord` will ignore the block that is passed to `count`.
+      #   frameworks. Before Rails 5.1, `ActiveRecord` will ignore the block that is passed to `count`.
       #   Other methods, such as `select`, will convert the association to an
       #   array and then run the block on the array. A simple work around to
       #   make `count` work with a block is to call `to_a.count {...}`.
@@ -19,14 +18,14 @@ module RuboCop
       #
       #   [source,ruby]
       #   ----
-      #   `Model.where(id: [1, 2, 3]).select { |m| m.method == true }.size`
+      #   Model.where(id: [1, 2, 3]).select { |m| m.method == true }.size
       #   ----
       #
       #   becomes:
       #
       #   [source,ruby]
       #   ----
-      #   `Model.where(id: [1, 2, 3]).to_a.count { |m| m.method == true }`
+      #   Model.where(id: [1, 2, 3]).to_a.count { |m| m.method == true }
       #   ----
       #
       # @example
@@ -55,8 +54,8 @@ module RuboCop
 
         def_node_matcher :count_candidate?, <<~PATTERN
           {
-            (send (block $(send _ ${:select :filter :find_all :reject}) ...) ${:count :length :size})
-            (send $(send _ ${:select :filter :find_all :reject} (:block_pass _)) ${:count :length :size})
+            (call (block $(call _ ${:select :filter :find_all :reject}) ...) ${:count :length :size})
+            (call $(call _ ${:select :filter :find_all :reject} (:block_pass _)) ${:count :length :size})
           }
         PATTERN
 
@@ -73,6 +72,7 @@ module RuboCop
             end
           end
         end
+        alias on_csend on_send
 
         private
 
@@ -101,7 +101,7 @@ module RuboCop
         end
 
         def negate_reject(corrector, node)
-          if node.receiver.send_type?
+          if node.receiver.call_type?
             negate_block_pass_reject(corrector, node)
           else
             negate_block_reject(corrector, node)
@@ -110,7 +110,7 @@ module RuboCop
 
         def negate_block_pass_reject(corrector, node)
           corrector.replace(
-            node.receiver.loc.expression.with(begin_pos: node.receiver.loc.begin.begin_pos),
+            node.receiver.source_range.with(begin_pos: node.receiver.loc.begin.begin_pos),
             negate_block_pass_as_inline_block(node.receiver)
           )
         end
